# Generated by Django 3.1.1 on 2020-09-16 06:14

from django.db import migrations, models
import django.db.models.deletion
import revpayment.models
from revpayment.settings import api_settings
import uuid


def get_buyer_label():
    buyer_label = api_settings.BUYER_CLASS._meta.label
    return buyer_label


def get_order_label():
    order_label = api_settings.ORDER_CLASS._meta.label
    return order_label


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(get_buyer_label()),
        migrations.swappable_dependency(get_order_label()),
    ]

    operations = [
        migrations.CreateModel(
            name='RedirectState',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('state', models.UUIDField(default=uuid.uuid4)),
                ('redirect_url', models.URLField(default=api_settings.WEB_HOST)),
                ('payment_type', models.CharField(choices=[('offline', 'offline'), ('ecpay', 'ecpay'), ('neweb', 'neweb')], default='neweb', max_length=20)),
                ('payment_subtype', models.CharField(choices=[('default', 'default'), ('credit', 'credit'), ('cvs_cod', 'cvs_cod'), ('cvs', 'cvs'), ('atm', 'atm'), ('web_atm', 'web_atm'), ('barcode', 'barcode')], default='default', max_length=20)),
                ('cart', models.TextField()),
                ('order_id', models.CharField(default=revpayment.models.gen_order_id, max_length=128)),
                ('order_type', models.CharField(default='default', max_length=128)),
                ('buyer', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=get_buyer_label())),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PaymentInfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('cart', models.TextField(blank=True, default=revpayment.models.empty_cart)),
                ('credit', models.IntegerField(default=0)),
                ('trading_slang', models.CharField(default=revpayment.models.random_digits, max_length=20)),
                ('owner', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='payment', to=get_buyer_label())),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Order',
            fields=[
                ('id', models.CharField(default=revpayment.models.gen_order_id, max_length=128, primary_key=True, serialize=False)),
                ('order_type', models.CharField(choices=[('default', 'default'), ('credit', 'credit')], default='default', max_length=128)),
                ('amount', models.FloatField(default=0)),
                ('title', models.CharField(default='order', max_length=100)),
                ('description', models.CharField(default='no description', max_length=256)),
                ('currency', models.CharField(choices=[('TWD', 'TWD'), ('USD', 'USD'), ('JPY', 'JPY')], default='TWD', max_length=8)),
                ('payment_type', models.CharField(choices=[('offline', 'offline'), ('ecpay', 'ecpay'), ('neweb', 'neweb')], default='neweb', max_length=20)),
                ('payment_subtype', models.CharField(choices=[('default', 'default'), ('credit', 'credit'), ('cvs_cod', 'cvs_cod'), ('cvs', 'cvs'), ('atm', 'atm'), ('web_atm', 'web_atm'), ('barcode', 'barcode')], default='default', max_length=20)),
                ('payment_status', models.CharField(choices=[('success', 'success'), ('failure', 'failure'), ('refunded', 'refunded'), ('logistics_created', 'logistics_created'), ('form_created', 'form_created'), ('code_generated', 'code_generated')], default='waiting', max_length=20)),
                ('data', models.TextField(blank=True, null=True)),
                ('cart', models.TextField(blank=True, null=True)),
                ('receiver_email', models.EmailField(max_length=254)),
                ('receiver_name', models.CharField(blank=True, max_length=20)),
                ('receiver_phone', models.CharField(blank=True, max_length=20)),
                ('receiver_address', models.CharField(blank=True, max_length=128)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('payment_transaction_detail', models.TextField(blank=True)),
                ('payment_redirect_detail', models.TextField(blank=True)),
                ('code_no', models.CharField(blank=True, max_length=128)),
                ('bank_code', models.CharField(blank=True, max_length=128)),
                ('bank_account', models.CharField(blank=True, max_length=128)),
                ('barcode_1', models.CharField(blank=True, max_length=128)),
                ('barcode_2', models.CharField(blank=True, max_length=128)),
                ('barcode_3', models.CharField(blank=True, max_length=128)),
                ('buyer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=get_buyer_label())),
            ],
            options={
            },
        ),
        migrations.CreateModel(
            name='Logistics',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('logistic_provider', models.CharField(choices=[('ecpay', 'ecpay')], default='ecpay', max_length=128)),
                ('logistic_type', models.CharField(choices=[('home', 'home'), ('cvs', 'cvs')], default='cvs', max_length=128)),
                ('logistic_subtype', models.CharField(choices=[('FAMI', 'FAMI'), ('FAMIC2C', 'FAMIC2C'), ('UNIMART', 'UNIMART'), ('UNIMARTC2C', 'UNIMARTC2C'), ('HILIFE', 'HIFIFE'), ('HILIFEC2C', 'HIFIFEC2C'), ('ECAN', 'ECAN'), ('TCAT', 'TCAT')], default='UNIMARTC2C', max_length=128)),
                ('logistic_status', models.CharField(choices=[('processing', 'processing'), ('uploading', 'uploading'), ('transit', 'transit'), ('delivered', 'delivered'), ('store_arrived', 'store_arrived')], default='processing', max_length=128)),
                ('detail', models.TextField(blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('order', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=get_order_label())),
            ],
            options={
            },
        ),
        migrations.CreateModel(
            name='Invoice',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('category', models.CharField(choices=[('B2B', 'B2B'), ('B2C', 'B2C')], default='B2C', max_length=10)),
                ('amount', models.IntegerField(default=0)),
                ('invoice_type', models.CharField(choices=[('neweb', 'neweb'), ('ecpay', 'ecpay')], default='neweb', max_length=64)),
                ('invoice_status', models.CharField(choices=[('success', 'success'), ('failure', 'failure'), ('void', 'void')], max_length=64)),
                ('invoice_number', models.CharField(max_length=128, null=True)),
                ('carrier_type', models.CharField(choices=[('no_carrier', 'no_carrier'), ('mobile', 'mobile'), ('npc', 'npc'), ('donation', 'donation'), ('default', 'default')], default='no_carrier', max_length=128, null=True)),
                ('carrier_number', models.CharField(blank=True, max_length=128, null=True)),
                ('uni_no', models.CharField(blank=True, max_length=128, null=True)),
                ('print_flag', models.BooleanField(default=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('detail', models.TextField(blank=True)),
                ('order', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=get_order_label())),
            ],
            options={
            },
        ),
    ]
